# Table of Contents

- [importing-and-updating-total-annual-costs-of-applications](<./importing-and-updating-total-annual-costs-of-applications.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Importing and Updating the Total Annual Costs of Applications](<./Importing-and-Updating-the-Total-Annual-Costs-of-Applications.md>)
  - [Overview](<./Importing-and-Updating-the-Total-Annual-Costs-of-Applications/Overview.md>)
  - [Prerequisites](<./Importing-and-Updating-the-Total-Annual-Costs-of-Applications/Prerequisites.md>)
  - [Importing Total Annual Costs](<./Importing-and-Updating-the-Total-Annual-Costs-of-Applications/Importing-Total-Annual-Costs.md>)
  - [Updating Total Annual Costs](<./Importing-and-Updating-the-Total-Annual-Costs-of-Applications/Updating-Total-Annual-Costs.md>)
  - [Related Information](<./Importing-and-Updating-the-Total-Annual-Costs-of-Applications/Related-Information.md>)
  - [Was this page helpful?](<./Importing-and-Updating-the-Total-Annual-Costs-of-Applications/Was-this-page-helpful.md>)
